#!/usr/bin/env python3


"""

""" """

This file is part of csharp-gentoodotnetinfo - .NET information tool for Gentoo.
Copyright (c) 2023, Maciej Barć <xgqt@riseup.net>
Licensed under the GNU GPL v2 License
SPDX-License-Identifier: GPL-2.0-or-later

csharp-gentoodotnetinfo is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
(at your option) any later version.

csharp-gentoodotnetinfo is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with csharp-gentoodotnetinfo.  If not, see <https://www.gnu.org/licenses/>.
"""


from os import chdir
from os import environ
from os import path

from shutil import rmtree
from subprocess import run
from sys import argv


def main():
    """! Main."""

    script_path = path.realpath(__file__)
    script_root = path.dirname(script_path)

    repo_root = path.realpath(path.join(script_root, ".."))
    source_path = path.join(repo_root, "Source")
    build_path = path.join(repo_root, "Build")

    v1_path = path.join(source_path, "v1")
    build_dir_path = path.join(build_path, "v1_dotnet_BuildDir")

    dotnet_executable = "dotnet"

    if len(argv) > 1:
        dotnet_executable = argv[1]

    subproject_path = path.join(v1_path, "gentoo-dotnet-info-app/GentooDotnetInfo")
    dotnet_output_directory = path.join(build_dir_path, "output")

    nuget_directory = path.join(build_dir_path, "nuget")
    nuget_packages_directory = path.join(nuget_directory, "nuget_packages")

    # We do not want to pollute user's "HOME" directory.
    if "NUGET_PACKAGES" not in environ:
        environ["NUGET_PACKAGES"] = nuget_packages_directory

    # Set this to "C" for easier debugging.
    environ["LANG"] = "C"

    # Sane build settings.
    environ["DOTNET_NOLOGO"] = "1"
    environ["DOTNET_SKIP_FIRST_TIME_EXPERIENCE"] = "1"
    environ["MSBUILDDISABLENODEREUSE"] = "1"
    environ["UseSharedCompilation"] = "false"

    # Turn off telemetry.
    environ["DOTNET_CLI_TELEMETRY_OPTOUT"] = "1"
    environ["POWERSHELL_TELEMETRY_OPTOUT"] = "1"
    environ["POWERSHELL_UPDATECHECK"] = "0"

    print(f" * Entering directory: {repo_root}")
    chdir(repo_root)

    print(f" * Entering directory: {subproject_path}")
    chdir(subproject_path)

    for object_directory in ["bin", "obj"]:
        if path.exists(object_directory):
            print(f" * Removing object directory: {object_directory}")

            rmtree(object_directory, ignore_errors=True)

    print(f" * Using dotnet executable: {dotnet_executable}")

    run(
        [
            dotnet_executable,
            "clean",
            "--verbosity",
            "quiet",
            "-maxCpuCount:1",
        ],
        check=True,
    )
    run(
        [
            dotnet_executable,
            "restore",
            "--verbosity",
            "quiet",
            "-maxCpuCount:1",
        ],
        check=True,
    )
    run(
        [
            dotnet_executable,
            "build",
            "--configuration",
            "Release",
            "--no-restore",
            "--no-self-contained",
            "--output",
            dotnet_output_directory,
            "--verbosity",
            "quiet",
            "-maxCpuCount:1",
        ],
        check=True,
    )
    run(
        [
            dotnet_executable,
            "exec",
            path.join(dotnet_output_directory, "GentooDotnetInfo.dll"),
        ],
        check=True,
    )


if __name__ == "__main__":
    main()
